package com.srs.comprehensive.service;

import com.srs.comprehensive.domain.SrsKnrdApply;
import com.srs.comprehensive.domain.SrsKnrdApprovalRecord;
import com.srs.comprehensive.domain.Vo.CphSearch;

import java.util.List;

/**
 * 困难审核Service接口
 * 
 * @author srs
 * @date 2024-03-19
 */
public interface ISrsKnrdApprovalRecordService 
{
    /**
     * 查询困难审核
     * 
     * @param id 困难审核主键
     * @return 困难审核
     */
    public SrsKnrdApprovalRecord selectSrsKnrdApprovalRecordById(Long id);

    /**
     * 查询困难审核列表
     * 
     * @param srsKnrdApprovalRecord 困难审核
     * @return 困难审核集合
     */
    public List<SrsKnrdApprovalRecord> selectSrsKnrdApprovalRecordList(SrsKnrdApprovalRecord srsKnrdApprovalRecord);

    /**
     * 新增困难审核
     * 
     * @param srsKnrdApprovalRecord 困难审核
     * @return 结果
     */
    public int insertSrsKnrdApprovalRecord(SrsKnrdApprovalRecord srsKnrdApprovalRecord);

    /**
     * 修改困难审核
     * 
     * @param srsKnrdApprovalRecord 困难审核
     * @return 结果
     */
    public int updateSrsKnrdApprovalRecord(SrsKnrdApprovalRecord srsKnrdApprovalRecord);

    /**
     * 批量删除困难审核
     * 
     * @param ids 需要删除的困难审核主键集合
     * @return 结果
     */
    public int deleteSrsKnrdApprovalRecordByIds(Long[] ids);

    /**
     * 删除困难审核信息
     * 
     * @param id 困难审核主键
     * @return 结果
     */
    public int deleteSrsKnrdApprovalRecordById(Long id);

    List<SrsKnrdApply> listView(CphSearch param);
}
